@@ -1527,6 +1527,9 @@ class SpeechGenerator(generator.Generator):
                             or (requireText \
                                 and 'Text' in pyatspi.listInterfaces(parent))):
                         text = self._script.utilities.displayedText(parent)
+                    if not text and parent.getRole() \
+                           in [pyatspi.ROLE_MENU, pyatspi.ROLE_PAGE_TAB]:
+                        text = parent.name
                     if text and len(text.strip()):
                         roleInfo = self._generateRoleName(parent)
                         if roleInfo:
@@ -1895,6 +1898,6 @@ class SpeechGenerator(generator.Generator):
         voices = _settingsManager.getSetting('voices')
         rv = voices.get(voicename)
         if rv and rv.get('established') == False:
-            rv = rv.pop('established')
+            rv.pop('established')
 
         return [rv]
