@@ -38,7 +38,7 @@ __author__    = "Tomas Cerha <cerha@brailcom.org>"
 __copyright__ = "Copyright (c) 2006-2008 Brailcom, o.p.s."
 __license__   = "LGPL"
 
-import gobject
+from gi.repository import GObject
 import re
 
 import chnames
@@ -190,6 +190,7 @@ class SpeechServer(speechserver.SpeechServer):
 
     def _init(self):
         self._client = client = speechd.SSIPClient('Orca', component=self._id)
+        client.set_priority(speechd.Priority.MESSAGE)
         if self._id != self.DEFAULT_SERVER_ID:
             client.set_output_module(self._id)
         self._current_voice_properties = {}
@@ -235,7 +236,7 @@ class SpeechServer(speechserver.SpeechServer):
         if familyLocale:
             lang = familyLocale.split('_')[0]
             if lang and len(lang) == 2:
-                self._send_command(self._client.set_language, lang)
+                self._send_command(self._client.set_language, str(lang))
         try:
             # This command is not available with older SD versions.
             set_synthesis_voice = self._client.set_synthesis_voice
@@ -349,9 +350,9 @@ class SpeechServer(speechserver.SpeechServer):
                         context.currentOffset = context.startOffset
                 elif t == speechserver.SayAllContext.COMPLETED:
                     context.currentOffset = context.endOffset
-                gobject.idle_add(orca_callback, context, t)
+                GObject.idle_add(orca_callback, context, t)
                 if t == speechserver.SayAllContext.COMPLETED:
-                    gobject.idle_add(self._say_all, iterator, orca_callback)
+                    GObject.idle_add(self._say_all, iterator, orca_callback)
             self._speak(context.utterance, acss, callback=callback,
                         event_types=self._CALLBACK_TYPE_MAP.keys())
         return False # to indicate, that we don't want to be called again.
@@ -425,7 +426,7 @@ class SpeechServer(speechserver.SpeechServer):
                 self._speak(utterance, acss)
 
     def sayAll(self, utteranceIterator, progressCallback):
-        gobject.idle_add(self._say_all, utteranceIterator, progressCallback)
+        GObject.idle_add(self._say_all, utteranceIterator, progressCallback)
 
     def speakCharacter(self, character, acss=None):
         self._apply_acss(acss)
